/*******************************************************************************
*   $FILE:  main.c
*   Atmel Corporation:  http://www.atmel.com \n
*   Support email:  touch@atmel.com
******************************************************************************/

/*  License
*   Copyright (c) 2010, Atmel Corporation All rights reserved.
*
*   Redistribution and use in source and binary forms, with or without
*   modification, are permitted provided that the following conditions are met:
*
*   1. Redistributions of source code must retain the above copyright notice,
*   this list of conditions and the following disclaimer.
*
*   2. Redistributions in binary form must reproduce the above copyright notice,
*   this list of conditions and the following disclaimer in the documentation
*   and/or other materials provided with the distribution.
*
*   3. The name of ATMEL may not be used to endorse or promote products derived
*   from this software without specific prior written permission.
*
*   THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
*   WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
*   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
*   SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
*   INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
*   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
*   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
*   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
*   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
*   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*----------------------------------------------------------------------------
                            compiler information
----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
                                include files
----------------------------------------------------------------------------*/
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#define __delay_cycles(n)     __builtin_avr_delay_cycles(n)
#define __enable_interrupt()  sei()

#include "touch_api.h"
#include "touch.h"
/*----------------------------------------------------------------------------
                            manifest constants
----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
                                    macros
----------------------------------------------------------------------------*/

#define GET_SENSOR_STATE(SENSOR_NUMBER) qt_measure_data.qt_touch_status.sensor_states[(SENSOR_NUMBER/8)] & (1 << (SENSOR_NUMBER % 8))
#define GET_ROTOR_SLIDER_POSITION(ROTOR_SLIDER_NUMBER) qt_measure_data.qt_touch_status.rotor_slider_values[ROTOR_SLIDER_NUMBER]

/*----------------------------------------------------------------------------
                            type definitions
----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
                                prototypes
----------------------------------------------------------------------------*/
extern void touch_measure();
extern void touch_init( void );
extern void init_system( void );
extern void init_timer_isr(void);
extern void set_timer_period(uint16_t);
/*----------------------------------------------------------------------------
                            Structure Declarations
----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
                                    macros
----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
                                global variables
----------------------------------------------------------------------------*/
/* Timer period in msec. */
uint16_t qt_measurement_period_msec = QT_MEASUREMENT_PERIOD_MS;
uint16_t time_ms_inc=0;
/*----------------------------------------------------------------------------
                                extern variables
----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------
                                static variables
----------------------------------------------------------------------------*/

/* flag set by timer ISR when it's time to measure touch */
volatile uint8_t time_to_measure_touch = 0u;

/* current time, set by timer ISR */
volatile uint16_t current_time_ms_touch = 0u;

/*============================================================================
Name    :   main
------------------------------------------------------------------------------
Purpose :   main code entry point
Input   :   n/a
Output  :   n/a
Notes   :
============================================================================*/


void ADC_init(void)
{
	
	ADMUX=(1<<REFS0);// For Aref=AVcc;
	
	ADCSRA=(1<<ADEN)|(7<<ADPS0);

}

int ADC_get(uint8_t ch)
{
	
	
	ch=ch&0b00000111;
	ADMUX|=ch;

	//Start Single conversion

	ADCSRA|=(1<<ADSC);

	//Wait for conversion to complete
	while(!(ADCSRA & (1<<ADIF)));

	//Clear ADIF by writing one to it
	ADCSRA|=(1<<ADIF);

	return(ADC);
}

void maintain_temperature_senzor()
{
	int temp = ADC_get(0);
	int t;
	t = temp / 2;
	
	
	if (temp > 50)
	//red
	{
		
		DDRA |= (1 << PA7);
		DDRC |= (1 << PC5);
		DDRC |= (1 << PC2);
		
		PORTA |= (1 << PA7);
		PORTC |= (1 << PC5);
		PORTC |= (1 << PC2);
		
		_delay_ms(3000);
		
		PORTA &= ~(1 << PA7);
		PORTC &= ~(1 << PC5);
		PORTC &= ~(1 << PC2);
		
		_delay_ms(3000);		
		
		
	}
	//blue
	else if(temp > 40)
	{
		DDRA |= (1 << PA6);
		DDRC |= (1 << PC6);
		DDRC |= (1 << PC3);
		
		PORTA |= (1 << PA6);
		PORTC |= (1 << PC6);
		PORTC |= (1 << PC3);
		
		_delay_ms(3000);
		
		PORTA &= ~(1 << PA6);
		PORTC &= ~(1 << PC6);
		PORTC &= ~(1 << PC3);
		
		_delay_ms(3000);
		
	}
	//green
	
	else
	{
		DDRA |= (1 << PA5);
		DDRC |= (1 << PC4);
		DDRC |= (1 << PC7);
		
		
		PORTA |= (1 << PA5);
		PORTC |= (1 << PC4);
		PORTC |= (1 << PC7);
		
		_delay_ms(3000);
		
		
		PORTA &= ~(1 << PA5);
		PORTC &= ~(1 << PC4);
		PORTC &= ~(1 << PC7);
		
		_delay_ms(3000);
		
	}
}

void maintain_temperature_user(int value)
{
	
	if (value > 80)
	//red
	{
		DDRA |= (1 << PA7);
		DDRC |= (1 << PC5);
		DDRC |= (1 << PC2);
		
		PORTA |= (1 << PA7);
		_delay_ms(3000);
		PORTA &= ~(1 << PA7);
		_delay_ms(3000);
		
		PORTC |= (1 << PC5);
		_delay_ms(3000);
		PORTC &= ~(1 << PC5);
		_delay_ms(3000);
		
		PORTC |= (1 << PC2);
		_delay_ms(3000);
		PORTC &= ~(1 << PC2);
		_delay_ms(3000);
		
	}
	//blue
	else if(value > 60)
	{
		DDRA |= (1 << PA6);
		DDRC |= (1 << PC6);
		DDRC |= (1 << PC3);
		
		PORTA |= (1 << PA6);
		_delay_ms(3000);
		PORTA &= ~(1 << PA6);
		_delay_ms(3000);
		
		PORTC |= (1 << PC6);
		_delay_ms(3000);
		PORTC &= ~(1 << PC6);
		_delay_ms(3000);
		
		PORTC |= (1 << PC3);
		_delay_ms(3000);
		PORTC &= ~(1 << PC3);
		_delay_ms(3000);
	}
	//red
	else
	{
		
		DDRA |= (1 << PA5);
		DDRC |= (1 << PC4);
		DDRC |= (1 << PC7);
		
		
		PORTA |= (1 << PA5);
		_delay_ms(3000);
		PORTA &= ~(1 << PA5);
		_delay_ms(3000);
		
		PORTC |= (1 << PC4);
		_delay_ms(3000);
		PORTC &= ~(1 << PC4);
		_delay_ms(3000);
		
		PORTC |= (1 << PC7);
		_delay_ms(3000);
		PORTC &= ~(1 << PC7);
		_delay_ms(3000);
		
	}
}


int main( void )
{

   /* initialise host app, pins, watchdog, etc */
    init_system();

    /* configure timer ISR to fire regularly */
    init_timer_isr();

	/* Initialize Touch sensors */
	touch_init();

	 
	uint8_t lastvalue = 0;
    
	int value = 0;
	
	/* loop forever */
    while(1)
    {
        touch_measure();
	

		if (qt_measure_data.qt_touch_status.rotor_slider_values[0] != 0)
		{
			uint8_t newvalue = qt_measure_data.qt_touch_status.rotor_slider_values[0];
			if (newvalue > lastvalue && newvalue < (lastvalue + 127))
				
				{				
					maintain_temperature_user(newvalue);
					value += 20;
					
				}
			if (newvalue < lastvalue && newvalue > (lastvalue - 127))
				{
				
					maintain_temperature_user(newvalue);
					value -= 20;
					
				}
			lastvalue = newvalue;
		}
		if (value > 100)
			value = 0;
		
		if ((qt_measure_data.qt_touch_status.sensor_states[0] & _BV(0)) != 0)
		{

			ADC_init();	
			maintain_temperature_senzor();
			
			
		}
		
		
		 
		
    }
}

